@@ -7,17 +7,16 @@ from typing import (
     Dict,
     Iterable,
     List,
-    Optional,
     Set,
 )
 
 from tensorlake.function_executor.proto.message_validator import MessageValidator
 
 from indexify.proto.executor_api_pb2 import (
+    Allocation,
     DesiredExecutorState,
     FunctionExecutorDescription,
     GetDesiredExecutorStatesRequest,
-    TaskAllocation,
 )
 from indexify.proto.executor_api_pb2_grpc import ExecutorAPIStub
 
@@ -28,10 +27,10 @@ from .function_executor.server.function_executor_server_factory import (
 )
 from .function_executor_controller import (
     FunctionExecutorController,
+    allocation_logger,
     function_executor_logger,
-    task_allocation_logger,
+    validate_allocation,
     validate_function_executor_description,
-    validate_task_allocation,
 )
 from .metrics.state_reconciler import (
     metric_state_reconciliation_errors,
@@ -54,7 +53,7 @@ class ExecutorStateReconciler:
         executor_id: str,
         function_executor_server_factory: FunctionExecutorServerFactory,
         base_url: str,
-        config_path: Optional[str],
+        config_path: str | None,
         cache_path: Path,
         blob_store: BLOBStore,
         channel_manager: ChannelManager,
@@ -67,7 +66,7 @@ class ExecutorStateReconciler:
             function_executor_server_factory
         )
         self._base_url: str = base_url
-        self._config_path: Optional[str] = config_path
+        self._config_path: str | None = config_path
         self._cache_path: Path = cache_path
         self._blob_store: BLOBStore = blob_store
         self._channel_manager: ChannelManager = channel_manager
@@ -76,19 +75,19 @@ class ExecutorStateReconciler:
         self._server_backoff_interval_sec: int = server_backoff_interval_sec
 
         # Mutable state. Doesn't need lock because we access from async tasks running in the same thread.
-        self._desired_states_reader_task: Optional[asyncio.Task] = None
-        self._reconciliation_loop_task: Optional[asyncio.Task] = None
+        self._desired_states_reader: asyncio.Task | None = None
+        self._reconciliation_loop_runner: asyncio.Task | None = None
         self._function_executor_controllers: Dict[str, FunctionExecutorController] = {}
         self._shutting_down_fe_ids: Set[str] = set()
-        self._last_server_clock: Optional[int] = None
+        self._last_server_clock: int | None = None
 
         self._last_desired_state_lock = asyncio.Lock()
         self._last_desired_state_change_notifier: asyncio.Condition = asyncio.Condition(
             lock=self._last_desired_state_lock
         )
-        self._last_desired_state: Optional[DesiredExecutorState] = None
+        self._last_desired_state: DesiredExecutorState | None = None
 
-    def get_desired_state(self) -> Optional[DesiredExecutorState]:
+    def get_desired_state(self) -> DesiredExecutorState | None:
         return self._last_desired_state
 
     def run(self):
@@ -96,17 +95,17 @@ class ExecutorStateReconciler:
 
         Never raises any exceptions. Doesn't block.
         """
-        if self._reconciliation_loop_task is not None:
+        if self._reconciliation_loop_runner is not None:
             self._logger.error(
-                "reconciliation loop task is already running, skipping run call"
+                "reconciliation loop aio task is already running, skipping run call"
             )
             return
 
-        self._reconciliation_loop_task = asyncio.create_task(
+        self._reconciliation_loop_runner = asyncio.create_task(
             self._reconciliation_loop(),
             name="state reconciler reconciliation loop",
         )
-        self._desired_states_reader_task = asyncio.create_task(
+        self._desired_states_reader = asyncio.create_task(
             self._desired_states_reader_loop(),
             name="state reconciler desired states stream reader",
         )
@@ -116,28 +115,28 @@ class ExecutorStateReconciler:
 
         Never raises any exceptions.
         """
-        if self._reconciliation_loop_task is not None:
-            self._reconciliation_loop_task.cancel()
+        if self._reconciliation_loop_runner is not None:
+            self._reconciliation_loop_runner.cancel()
             try:
-                await self._reconciliation_loop_task
+                await self._reconciliation_loop_runner
             except asyncio.CancelledError:
                 # Expected cancellation, nothing to do.
                 pass
             self._logger.info("reconciliation loop is shutdown")
 
-        if self._desired_states_reader_task is not None:
-            self._desired_states_reader_task.cancel()
+        if self._desired_states_reader is not None:
+            self._desired_states_reader.cancel()
             try:
-                await self._desired_states_reader_task
+                await self._desired_states_reader
             except asyncio.CancelledError:
                 # Expected cancellation, nothing to do.
                 pass
             self._logger.info("desired states stream reader loop is shutdown")
 
         # Now all the aio tasks exited so nothing will intervene with our actions from this point.
-        fe_shutdown_tasks: List[asyncio.Task] = []
+        fe_shutdown_aio_tasks: List[asyncio.Task] = []
         for fe_controller in self._function_executor_controllers.values():
-            fe_shutdown_tasks.append(
+            fe_shutdown_aio_tasks.append(
                 asyncio.create_task(
                     fe_controller.shutdown(),
                     name=f"Shutdown Function Executor {fe_controller.function_executor_id()}",
@@ -145,8 +144,8 @@ class ExecutorStateReconciler:
             )
 
         # Run all the shutdown tasks concurrently and wait for them to complete.
-        for task in fe_shutdown_tasks:
-            await task
+        for aio_task in fe_shutdown_aio_tasks:
+            await aio_task
 
         self._function_executor_controllers.clear()
         self._logger.info("state reconciler is shutdown")
@@ -154,10 +153,10 @@ class ExecutorStateReconciler:
     async def _desired_states_reader_loop(self):
         """Reads the desired states stream from Server and processes it.
 
-        Never raises any exceptions. Get cancelled via aio task cancellation.
+        Never raises any exceptions. Gets cancelled via aio task cancellation.
         """
         while True:
-            desired_states_stream: Optional[AsyncIterable[DesiredExecutorState]] = None
+            desired_states_stream: AsyncIterable[DesiredExecutorState] | None = None
             try:
                 stub = ExecutorAPIStub(await self._channel_manager.get_shared_channel())
                 # Report state once before starting the stream so Server
@@ -235,7 +234,7 @@ class ExecutorStateReconciler:
         """Continuously reconciles the desired state with the current state.
 
         Never raises any exceptions. Get cancelled via aio task cancellation."""
-        last_reconciled_state: Optional[DesiredExecutorState] = None
+        last_reconciled_state: DesiredExecutorState | None = None
         while True:
             async with self._last_desired_state_lock:
                 # Comparing object identities (references) is enough here to not reconcile
@@ -261,9 +260,9 @@ class ExecutorStateReconciler:
         """
         for attempt in range(_RECONCILIATION_RETRIES):
             try:
-                # Reconcile FEs first because Tasks depend on them.
+                # Reconcile FEs first because allocations depend on them.
                 self._reconcile_function_executors(desired_state.function_executors)
-                self._reconcile_task_allocations(desired_state.task_allocations)
+                self._reconcile_allocations(desired_state.allocations)
                 return
             except Exception as e:
                 self._logger.error(
@@ -375,7 +374,7 @@ class ExecutorStateReconciler:
         # We are not cancelling this aio task in self.shutdown(). Because of this the code here should
         # not fail if the FE controller is not found in internal data structures. It can be removed
         # by self.shutdown() at any time while we're running this aio task.
-        fe_controller: Optional[FunctionExecutorController] = (
+        fe_controller: FunctionExecutorController | None = (
             self._function_executor_controllers.get(function_executor_id)
         )
         if fe_controller is None:
@@ -385,21 +384,19 @@ class ExecutorStateReconciler:
         self._function_executor_controllers.pop(function_executor_id, None)
         self._shutting_down_fe_ids.discard(function_executor_id)
 
-    def _reconcile_task_allocations(self, task_allocations: Iterable[TaskAllocation]):
-        valid_task_allocations: List[TaskAllocation] = self._valid_task_allocations(
-            task_allocations
-        )
-        for task_allocation in valid_task_allocations:
-            self._reconcile_task_allocation(task_allocation)
+    def _reconcile_allocations(self, allocations: Iterable[Allocation]):
+        valid_allocations: List[Allocation] = self._valid_allocations(allocations)
+        for allocation in valid_allocations:
+            self._reconcile_allocation(allocation)
 
-        # Cancel tasks that are no longer in the desired state.
+        # Cancel allocs that are no longer in the desired state.
         # FE ID => [Allocation ID]
         desired_alloc_ids_per_fe: Dict[str, List[str]] = {}
-        for task_allocation in valid_task_allocations:
-            if task_allocation.function_executor_id not in desired_alloc_ids_per_fe:
-                desired_alloc_ids_per_fe[task_allocation.function_executor_id] = []
-            desired_alloc_ids_per_fe[task_allocation.function_executor_id].append(
-                task_allocation.allocation_id
+        for allocation in valid_allocations:
+            if allocation.function_executor_id not in desired_alloc_ids_per_fe:
+                desired_alloc_ids_per_fe[allocation.function_executor_id] = []
+            desired_alloc_ids_per_fe[allocation.function_executor_id].append(
+                allocation.allocation_id
             )
 
         for fe_controller in self._function_executor_controllers.values():
@@ -409,54 +406,52 @@ class ExecutorStateReconciler:
                     desired_alloc_ids_per_fe[fe_controller.function_executor_id()]
                 )
             else:
-                # No tasks desired for this FE, so cancel all its tasks.
+                # No allocations desired for this FE, so cancel all its allocations.
                 desired_fe_alloc_ids: Set[str] = set()
-            actual_fe_alloc_ids: Set[str] = set(fe_controller.task_allocation_ids())
+            actual_fe_alloc_ids: Set[str] = set(fe_controller.allocation_ids())
             alloc_ids_to_remove: Set[str] = actual_fe_alloc_ids - desired_fe_alloc_ids
             for alloc_id in alloc_ids_to_remove:
-                fe_controller.remove_task_allocation(alloc_id)
+                fe_controller.remove_allocation(alloc_id)
 
-    def _reconcile_task_allocation(self, task_allocation: TaskAllocation):
-        """Reconciles a single TaskAllocation with the desired state.
+    def _reconcile_allocation(self, allocation: Allocation):
+        """Reconciles a single Allocation with the desired state.
 
         Doesn't raise any exceptions.
         """
         function_executor_controller: FunctionExecutorController = (
-            self._function_executor_controllers[task_allocation.function_executor_id]
+            self._function_executor_controllers[allocation.function_executor_id]
         )
-        if function_executor_controller.has_task_allocation(
-            task_allocation.allocation_id
-        ):
-            # Nothing to do, task already exists and it's immutable.
+        if function_executor_controller.has_allocation(allocation.allocation_id):
+            # Nothing to do, allocation already exists and it's immutable.
             return
 
-        function_executor_controller.add_task_allocation(task_allocation)
+        function_executor_controller.add_allocation(allocation)
 
-    def _valid_task_allocations(self, task_allocations: Iterable[TaskAllocation]):
-        valid_task_allocations: List[TaskAllocation] = []
-        for task_allocation in task_allocations:
-            task_allocation: TaskAllocation
-            logger = task_allocation_logger(task_allocation, self._logger)
+    def _valid_allocations(self, allocations: Iterable[Allocation]):
+        valid_allocations: List[Allocation] = []
+        for allocation in allocations:
+            allocation: Allocation
+            logger = allocation_logger(allocation, self._logger)
 
             try:
-                validate_task_allocation(task_allocation)
+                validate_allocation(allocation)
             except ValueError as e:
                 # There's no way to report this error to Server so just log it.
                 logger.error(
-                    "received invalid TaskAllocation from Server, dropping it from desired state",
+                    "received invalid Allocation from Server, dropping it from desired state",
                     exc_info=e,
                 )
                 continue
 
             if (
-                task_allocation.function_executor_id
+                allocation.function_executor_id
                 not in self._function_executor_controllers
             ):
                 logger.error(
-                    "received TaskAllocation for a Function Executor that doesn't exist, dropping it from desired state"
+                    "received Allocation for a Function Executor that doesn't exist, dropping it from desired state"
                 )
                 continue
 
-            valid_task_allocations.append(task_allocation)
+            valid_allocations.append(allocation)
 
-        return valid_task_allocations
+        return valid_allocations
